@@ -34,6 +34,8 @@ class data(TypedDict):
     R27: float
     R28: float
     R29: float
+    const1: float
+    const2: float
     belt_geometry: np.ndarray
 
 class GeometrySolver:
@@ -70,6 +72,8 @@ class GeometrySolver:
         R27 = None,
         R28 = None,
         R29 = None,
+        const1 = None,
+        const2 = None,
         belt_geometry = None
     )
 
@@ -84,11 +88,13 @@ class GeometrySolver:
 
         self.preprocessed_data['d'] = data['shell_size']['d']
         self.preprocessed_data['belt_geometry'] = np.array([data['belt_coord']['x'], data['belt_coord']['y']])
+        self.preprocessed_data['R13'] = self.preprocessed_data['R8'] - data['shell_size']['const2']
+        self.preprocessed_data['R15'] = self.preprocessed_data['R14'] - data['shell_size']['const1']
 
 
     def _get_shell_coord(self, p_data):
 
-        const1 = p_data['R15'] - p_data['R14']
+        const1 = p_data['R14'] - p_data['R15']
         const2 = p_data['R8'] - p_data['R13']
 
         # Рассчитываем иксы всех точек корпуса ОФС
@@ -329,7 +335,10 @@ class GeometrySolver:
         # Определяем hs_p для аэродинамики (форма оживальной части)
         hsp = self._get_hs_p(p_data=p_data, R_real=Roj)
 
-
+        # Сохраняем псевдо-варьируемые параметры
+        R13 = round(p_data['R13'], 4)
+        R15 = round(p_data['R15'], 4)
+        
         state[GeometrySolver.name] = dict(
             corpus_coord=self.corpus_coords,
             explosive_coord=self.explosives_coords,
@@ -337,6 +346,8 @@ class GeometrySolver:
             belt_coord=self.belt_nodes,
             Roj=Roj,
             roj=roj,
+            R13=R13,
+            R15=R15,
             hs_p=hsp,
             L_corp=L_corp,
             L_all=L_all,
