@@ -614,7 +614,7 @@ class APFSDMccSolver(ABCSolver):
         la = p_data['la']
 
         rlen = p_data['len'] * la
-        mass = 0.25 * p_data['form_koef'] * np.pi * p_data['rho_db'] * rlen * p_data['d'] ** 2
+        mass = 0.25 * p_data['form_koef'] * p_data['rho_db'] * rlen * np.pi * (p_data['d'] ** 2 - p_data['da'] ** 2)
 
         return dict(rlen=rlen, mass=mass)
 
