@@ -196,6 +196,7 @@ class PenetrationHeadSolver:
 
         V = np.zeros(10)
         Px = np.zeros(10)
+        Fx = np.zeros(10)
         kf = np.zeros(10)
         S = np.zeros(10)
         t = np.zeros(10)
@@ -220,6 +221,7 @@ class PenetrationHeadSolver:
                 Px[i] = (0.7 * N * kf[i] * rho_zv * V[i] ** 2) / (1 + 0.259 * (rho_zv * N / Cqi))
                 dt = (k1 / k2) * (V[i - 1] - V[i]) / (V[i - 1] * V[i])
                 t[i] = t[i - 1] + dt
+                Fx[i] = Px[i] * S[i]
 
             else:
                 k1 = 0.1 * (q + 0.33 * S[i] * rho * N1 * di)
@@ -230,7 +232,7 @@ class PenetrationHeadSolver:
                 dt = k1 / np.sqrt(k2 * k3) * (np.arctan(V[i-1] * np.sqrt(k2/k3)) - np.arctan(V[i] * np.sqrt(k2/k3)))
                 t[i] = t[i - 1] + dt
                 Px[i] = (0.7 * N2 * kf[i] * rho * V[i] ** 2 + N3) / (1 + 0.259 * (rho * N1 / Cqi))
-
+                Fx[i] = Px[i] * S[i]
 
 
         # Расчёт изменения скорости и давления преграды по сечениям
@@ -253,7 +255,7 @@ class PenetrationHeadSolver:
 
 
 
-        results = {'x_with_fuse': x_sec, 't': t, 'V': V, 'S': S, 'kf': kf, 'Px': Px,}
+        results = {'x_with_fuse': x_sec, 't': t, 'V': V, 'S': S, 'kf': kf, 'Px': Px, 'Fx': Fx}
 
         # my_plot(x=x_sec ,y=V, title='Изменение скорости снаряда при проникании на длину ГЧ \n (преграда СПГ Vc=105)')
         # print('Давление преграды: ', Px * 1E-6)
@@ -417,9 +419,7 @@ class PenetrationHeadSolver:
         mu_c = data['mu_c_expl']
         px = pen_res['Px'][-1]
         Rx = sec_res['Ri'][-1]
-
         Sn = np.zeros(sec_count)
-        Fn = np.zeros(sec_count)
         Nn = np.zeros(sec_count)
         pc = np.zeros(sec_count)
         sigma_x = np.zeros(sec_count)
@@ -435,8 +435,7 @@ class PenetrationHeadSolver:
 
             # Площадь корпуса снаряда в сечении
             Sn[i] = np.pi * (Rn**2 - rn**2)
-            # Сила сопротивления преграды
-            Fn[i] = px * np.pi * (Rx**2 - Rn**2)
+
             # Сжимающая сила
             if i != 9:
                 # формула для гч
@@ -480,7 +479,7 @@ class PenetrationHeadSolver:
 
 
 
-        results = {'F': Fn, 'S': Sn, 'pc': pc, 'N': Nn, 'sigma_x': sigma_x, 'sigma_r': sigma_r,
+        results = {'S': Sn, 'pc': pc, 'N': Nn, 'sigma_x': sigma_x, 'sigma_r': sigma_r,
                    'sigma_t': sigma_t, 'sigma_pr': sigma_pr}
 
         return results
