@@ -1440,16 +1440,16 @@ class APFSDStrengthSolver(ABCSolver):
         p_max = p_data['p_max']
 
         if la >= x > (x_db_0 + l_db):
-            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+            sigma = -(m_bt + m_k * (1. - x / la)) / m_total
             sigma *= s * p_max / sk
             return sigma
         if (x_db_0 + l_db) >= x > x_db_0:
-            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+            sigma = -(m_bt + m_k * (1. - x / la)) / m_total
             sigma *= s * p_max / sk
             sigma += Fg * (l_db + x_db_0 - x) / (l_db * sk)
             return sigma
-        if x_db_0 >= x > 0.:
-            sigma = -(m_bt + (m_k + m_pl) * (1. - x / la)) / m_total
+        if x_db_0 >= x >= 0.:
+            sigma = -(m_bt + m_k * (1. - x / la)) / m_total
             sigma *= s * p_max / sk
             sigma += Fg / sk
             return sigma
